@@ -82,6 +82,7 @@ static const AVFilter * const filter_list[] = {
     &ff_af_atilt,
     &ff_af_atrim,
     &ff_af_axcorrelate,
+    &ff_af_azmq,
     &ff_af_bandpass,
     &ff_af_bandreject,
     &ff_af_bass,
@@ -464,6 +465,7 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_xstack,
     &ff_vf_yadif,
     &ff_vf_yaepblur,
+    &ff_vf_zmq,
     &ff_vf_zoompan,
     &ff_vf_zscale,
     &ff_vf_hstack_vaapi,
